pg.ddx.io  pgsql-performance@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Stefan Kaltenbrunner <stefan@kaltenbrunner.cc>
To: Bruce Momjian <pgman@candle.pha.pa.us>
Cc: Qingqing Zhou <zhouqq@cs.toronto.edu>
Cc: pgsql-hackers@postgresql.org
Subject: Re: Test request for Stats collector performance improvement
Date: Fri, 16 Jun 2006 20:14:47 +0200
Message-ID: <4492F517.7060405@kaltenbrunner.cc> (raw)
In-Reply-To: <200606161624.k5GGO3N03466@candle.pha.pa.us>
References: <200606161624.k5GGO3N03466@candle.pha.pa.us>

Bruce Momjian wrote:
> Stefan Kaltenbrunner wrote:
>> Bruce Momjian wrote:
>>> OK, based on reports I have seen, generally stats_query_string adds 50%
>>> to the total runtime of a "SELECT 1" query, and the patch reduces the
>>> overhead to 25%.
>> that is actually not true for both of the platforms(a slow OpenBSD
>> 3.9/x86 and a very fast Linux/x86_64) I tested on. Both of them show
>> virtually no improvement with the patch and even worst it causes
>> considerable (negative) variance on at least the Linux box.
> 
> I see the results I suggested on OpenBSD that you reported.
> 
>> OpenBSD 3.9-current/x86:
>>
>> without stats:
>>     0m6.79s real     0m1.56s user     0m1.12s system
>>
>> -HEAD + stats:
>>     0m10.44s real     0m2.26s user     0m1.22s system
>>
>> -HEAD + stats + patch:
>>     0m10.68s real     0m2.16s user     0m1.36s system

yep those are very stable even over a large number of runs

> 
> and I got similar results reported from a Debian:
> 
> 	Linux 2.6.16 on a single processor HT 2.8Ghz Pentium compiled
> 	with gcc 4.0.4.
> 
> 	> > real        0m3.306s
> 	> > real        0m4.905s
> 	> > real        0m4.448s
> 
> I am unclear on the cuase for the widely varying results you saw in
> Debian.
> 

I can reproduce the widely varying results on a number of x86 and x86_64
based Linux boxes here (Debian,Fedora and CentOS) though I cannot
reproduce it on a Fedora core 5/ppc box.
All the x86 boxes are SMP - while the ppc one is not - that might have
some influence on the results.

Stefan



view thread (21+ messages)  latest in thread

Message-ID: <4492F517.7060405@kaltenbrunner.cc>
Permalink:  ../4492F517.7060405@kaltenbrunner.cc/
Also on:    postgresql.org/message-id/4492F517.7060405@kaltenbrunner.cc

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-performance@postgresql.org
  Cc: stefan@kaltenbrunner.cc, pgman@candle.pha.pa.us, zhouqq@cs.toronto.edu, pgsql-hackers@postgresql.org
  Subject: Re: Test request for Stats collector performance improvement
  In-Reply-To: <4492F517.7060405@kaltenbrunner.cc>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox